@@ -25,7 +25,9 @@ defined in this file.
 from __future__ import unicode_literals
 from __future__ import print_function
 
+import datetime
 import logging
+import pytz
 import re
 import time
 from collections import OrderedDict
@@ -562,17 +564,17 @@ class DownloadPage(Page):
             else:
                 imagedict[desc] = [img]
         # Now we have our data, sort the dict using the weight we
-        # calculated earlier...for our purposes we can just use the
-        # weight of the first image.
+        # calculated earlier. We use the max score of all arches in
+        # each group of images.
         imagedict = OrderedDict(sorted(imagedict.items(),
-                                       key=lambda x: x[1][0]['score'],
+                                       key=lambda x: max(img['score'] for img in x[1]),
                                        reverse=True))
         # ...and sort the arches (just so they don't move around in
         # each new page and confuse people).
         arches = sorted(arches)
 
         # Now generate the table.
-        table = '{| class="wikitable sortable collapsible" width=100%\n|-\n'
+        table = '{| class="wikitable sortable mw-collapsible" width=100%\n|-\n'
         # Start of the header row...
         table += '! Image'
         for arch in arches:
@@ -603,6 +605,91 @@ class DownloadPage(Page):
         pass
 
 
+class AMIPage(Page):
+    """A page containing EC2 AMI links for a given event. Is included
+    in the Cloud validation page to make it easy for people to find
+    the correct AMIs.
+    """
+    def __init__(self, site, event, info=None, modular=False):
+        _dist = "Fedora"
+        if modular:
+            _dist = "Fedora Modular"
+        wikiname = "Template:{0} {1} AMI".format(_dist, event.version)
+        self.summary = "Relval bot-created AMI page for {0} {1}".format(
+            _dist, event.version)
+        super(AMIPage, self).__init__(site, wikiname, info)
+        self.event = event
+
+    @property
+    def seedtext(self):
+        """A table of all the AMIs for the compose for this event. We
+        have to query this information out of datagrepper, that's the
+        only place where it's available.
+        """
+        text = ""
+        # first, let's get the information out of datagrepper. We'll
+        # ask for messages up to 2 days after the event date.
+        date = fedfind.helpers.parse_cid(self.event.ff_release.cid, dic=True)['date']
+        start = datetime.datetime.strptime(date, '%Y%m%d').replace(tzinfo=pytz.utc)
+        end = start + datetime.timedelta(days=2)
+        # convert to epoch (this is what datagrepper wants). In Python
+        # 3 we can use just .timestamp() but sadly not in Python 2.
+        # https://stackoverflow.com/questions/6999726
+        epoch = datetime.datetime.utcfromtimestamp(0).replace(tzinfo=pytz.utc)
+        start = (start - epoch).total_seconds()
+        end = (end - epoch).total_seconds()
+        url = "https://apps.fedoraproject.org/datagrepper/raw"
+        url += "?topic=org.fedoraproject.prod.fedimg.image.publish"
+        url += "&start={0}&end={1}".format(start, end)
+        json = fedfind.helpers.download_json(url)
+        msgs = json['raw_messages']
+        # handle pagination
+        for page in range(2, json['pages'] + 1):
+            newurl = url + "&page={0}".format(page)
+            newjson = fedfind.helpers.download_json(newurl)
+            msgs.extend(newjson['raw_messages'])
+
+        # now let's find the messages for our event compose
+        ours = [msg['msg'] for msg in msgs if msg['msg']['compose'] == self.event.ff_release.cid]
+
+        def _table_line(msg):
+            """Convenience function for generating a table line."""
+            destination = msg['destination']
+            ami = msg['extra']['id']
+            url = "https://redirect.fedoraproject.org/console.aws.amazon.com/ec2/v2/home?"
+            url += "region={0}#LaunchInstanceWizard:ami={1}".format(destination, ami)
+            return "| {0}\n| {1}\n| [{2} Launch in EC2]\n|-\n".format(destination, ami, url)
+
+        def _table(arch, virttype, voltype):
+            """Convenience function for adding a table."""
+            ret = "== {0} {1} {2} AMIs ==\n\n".format(arch, virttype, voltype)
+            ret += '{| class="wikitable sortable mw-collapsible'
+            if arch != 'x86_64' or virttype != 'hvm' or voltype != 'standard':
+                # we expand the x86_64 hvm standard table by default
+                ret += ' mw-collapsed'
+            ret += '" width=100%\n|-\n'
+            ret += "! Region !! AMI ID !! Direct launch link\n|-\n"
+            # find the right messages for this arch and types
+            relevants = [msg for msg in ours if
+                         msg['architecture'] == arch and
+                         msg['extra']['virt_type'] == virttype and
+                         msg['extra']['vol_type'] == voltype]
+            # sort the messages by region so the table is easier to scan
+            relevants.sort(key=lambda x:x['destination'])
+            for msg in relevants:
+                ret += _table_line(msg)
+            ret += "|}\n\n"
+            return ret
+
+        # now let's create and populate the tables
+        for arch in ('x86_64', 'arm64'):
+            for virttype in ('hvm',):
+                for voltype in ('standard', 'gp2'):
+                    text += _table(arch, virttype, voltype)
+
+        return text
+
+
 class TestDayPage(Page):
     """A Test Day results page. Usually contains table(s) with test
     cases as the column headers and users as the rows - each row is
