@@ -518,7 +518,7 @@ class ResultRow(TestInstance):
                     continue
                 except IndexError:
                     try:
-                        altname = cell.strip().strip('[]').split()[1]
+                        altname = cell.strip().strip('[]').split(maxsplit=1)[1]
                     except IndexError:
                         altname = None
             if '{{result' in cell or '{{testresult' in cell:
