@@ -68,9 +68,7 @@ class Wiki(mwclient.Site):
     """Extends the mwclient.Site class with some extra capabilities."""
     # parent class has a whole bunch of args, so just pass whatever through.
     # always init this the same as a regular mwclient.Site instance.
-    def __init__(self, host='', *args, **kwargs):
-        if not host:
-            host = ('https', 'fedoraproject.org')
+    def __init__(self, host='fedoraproject.org', *args, **kwargs):
         super(Wiki, self).__init__(host, *args, **kwargs)
         # override the 'pages' property so it returns wikitcms Pages when
         # appropriate
@@ -171,9 +169,12 @@ class Wiki(mwclient.Site):
         return [m['title'].replace('Template:', '')
                 .replace(' modular test matrix', '') for m in self.modular_matrices]
 
-    def login(self, username=None, password=None, *args, **kwargs):
-        """Login method, overridden to read credentials from file if
-        not provided, and use openidc auth when necessary.
+    def login(self, *args, **kwargs):
+        """Login method, overridden to use openidc auth when necessary.
+        This will open a browser window and run through FAS auth on
+        the first use, then a token will be saved that will allow auth
+        for a while, when the token expires, the web auth process will
+        pop up again.
         """
         use_openidc = False
         # This probably breaks on private wikis, but wikitcms isn't
@@ -183,49 +184,34 @@ class Wiki(mwclient.Site):
             host = host[1]
         if host.endswith('fedoraproject.org') and self.version[:2] >= (1, 29):
             use_openidc = True
-        if use_openidc:
-            # Fedora wiki since upgrade to 1.29 doesn't allow native
-            # mediawiki auth with FAS creds any more, it only allows
-            # auth via OpenID Connect. For this case we set up an
-            # openidc auther, call site_init() to trigger auth and
-            # update the site properties, and return. username and
-            # password, and the credentials file, are entirely ignored
-            # on this path.
-            if OpenIDCClient is None:
-                raise ImportError('python-openidc-client is needed for OIDC')
-            if OpenIDCClientAuther is None:
-                raise ImportError('python-openidc-client 0.4.0 or higher is '
-                                  'required for OIDC')
-            client = OpenIDCClient(
-                app_identifier='wikitcms',
-                id_provider='https://id.{0}/openidc/'.format(host),
-                id_provider_mapping={'Token': 'Token',
-                                     'Authorization': 'Authorization'},
-                client_id='wikitcms',
-                client_secret='notsecret',
-                useragent='wikitcms')
+        if not use_openidc:
+            # just work like mwclient
+            return super(Wiki, self).login(*args, **kwargs)
 
-            auther = OpenIDCClientAuther(client,
-                                         ['openid', 'https://fedoraproject.org/wiki/api'])
+        # Fedora wiki since upgrade to 1.29 doesn't allow native
+        # mediawiki auth with FAS creds any more, it only allows
+        # auth via OpenID Connect. For this case we set up an
+        # openidc auther, call site_init() to trigger auth and
+        # update the site properties, and return.
+        if OpenIDCClient is None:
+            raise ImportError('python-openidc-client is needed for OIDC')
+        if OpenIDCClientAuther is None:
+            raise ImportError('python-openidc-client 0.4.0 or higher is '
+                              'required for OIDC')
+        client = OpenIDCClient(
+            app_identifier='wikitcms',
+            id_provider='https://id.{0}/openidc/'.format(host),
+            id_provider_mapping={'Token': 'Token',
+                                 'Authorization': 'Authorization'},
+            client_id='wikitcms',
+            client_secret='notsecret',
+            useragent='wikitcms')
 
-            self.connection.auth = auther
-            self.site_init()
-            return
+        auther = OpenIDCClientAuther(client,
+                                     ['openid', 'https://fedoraproject.org/wiki/api'])
 
-        # From here on is the old code for native mediawiki auth with
-        # FAS credentials. Will likely be removed in a future release.
-        if not self.credentials and (not username or not password):
-            # self.credentials being populated means a *previous* call
-            # to this method set username and password, we should not
-            # override them.
-            creds = hl.read_creds()
-            if creds:
-                if not username:
-                    username = list(creds.keys())[0]
-                if not password:
-                    password = creds.get(username)
-
-        super(Wiki, self).login(username, password, *args, **kwargs)
+        self.connection.auth = auther
+        self.site_init()
 
     def add_to_category(self, page_name, category_name, summary=''):
         """Add a given page to a given category if it is not already a
